SUBROUTINE DYPGRIN(DEPMIN,NFILTER,DEPMAX,DSBOT)
!
!  The variables COR, FSM, DUM, DVM are defined.
!  DEPTH is called to set up the vertical distribution of
!  sigma-layers
!  The bottom matrix H is Shapiro-filtered NFILTER times.
!  The maximum depth, DEPMAX, in the model region is computed
!  The bottom friction coefficients CBC are computed.
!
USE STATE
IMPLICIT NONE
REAL DEPMIN,DEPMAX,DSBOT,AREA
INTEGER NFILTER
!
INTEGER I,J,IF
REAL H2(IM,JM)
REAL HAVER1,HAVER2
INTEGER NUM1,NUM2
!
!Read the depth matrix from the file 'bottom1km.dat',
!and place it in H.
! The present bottom matrix is based on a matrix produced by Trygve Sagberg, Geophysics Department,
! University of Bergen
! for studies of the circulation in the fjord system around Osteroy.
!
DO J = 1,JM
   DO I = 1,IM
      READ(10,*)H(I,J)
   END DO
END DO   
!
DO J = 1,JM
  H(IM,J) = 0.
END DO
!
!  Open up some passages.
!
H(15,8) = 0.5*(H(16,8)+H(15,9))
H(15,7) = 0.5*(H(16,7)+H(15,6))
!
H(10,18) = (H(10,19)+H(10,17)+H(9,18))/3.
!
H(9,19) = H(10,19)
H(9,20) = H(10,20)
H(9,21) = H(10,21)
!
!  Compute an average depth interior to the open boundaries.
!
HAVER1 = 0.
NUM1 = 0
DO I = 8,15
  DO J = 10,15
    IF (H(I,J).GT.0.) THEN
      NUM1 = NUM1 + 1
      HAVER1 = HAVER1 + H(I,J)
    ENDIF
  END DO
END DO
!
!  Produce a flat bottom through the in and outflow channels.
!
HAVER1 = HAVER1/NUM1
DO I = 1,9
  DO J = 13,14
    H(I,J) = HAVER1
  END DO
END DO
HAVER2 = 0.
NUM2 = 0
DO I = 12,18
  DO J = 7,10
    IF (H(I,J).GT.0.) THEN
      NUM2 = NUM2 + 1
      HAVER2 = HAVER2 + H(I,J)
    ENDIF
  END DO
END DO
HAVER2 = HAVER2/NUM2
DO I = 15,18
  DO J = 1,9
    H(I,J) = HAVER2
  END DO
END DO

!
!  Shapiro filter H NFILTER times.
!
IF (NFILTER.GE.1) THEN
  DO IF = 1,NFILTER
    H2 = H
    DO I = 1,IM
      DO J = 2,JM-1
        IF (H(I,J).GT.0.) THEN
          IF (H(I,J-1).GT.0. .AND. H(I,J+1).GT.0. ) THEN
            H2(I,J) = 0.25*H(I,J-1) + 0.5*H(I,J) + 0.25*H(I,J+1)
          ELSEIF (H(I,J-1).GT.0. .AND. H(I,J+1).LE.0. ) THEN
            H2(I,J) = 0.25*H(I,J-1) + 0.75*H(I,J)
          ELSEIF (H(I,J-1).LE.0. .AND. H(I,J+1).GT.0. ) THEN
            H2(I,J) = 0.25*H(I,J+1) + 0.75*H(I,J)
          ENDIF
        ENDIF
      END DO
    END DO
    H = H2
    DO I = 2,IM-1
      DO J = 1,JM
        IF (H(I,J).GT.0.) THEN
          IF (H(I-1,J).GT.0. .AND. H(I+1,J).GT.0. ) THEN
            H2(I,J) = 0.25*H(I-1,J) + 0.5*H(I,J) + 0.25*H(I+1,J)
          ELSEIF (H(I-1,J).GT.0. .AND. H(I+1,J).LE.0. ) THEN
            H2(I,J) = 0.25*H(I-1,J) + 0.75*H(I,J)
          ELSEIF (H(I-1,J).LE.0. .AND. H(I+1,J).GT.0. ) THEN
            H2(I,J) = 0.25*H(I+1,J) + 0.75*H(I,J)
          ENDIF
        ENDIF
      END DO
    END DO
    H = H2
!
!  Keep flat bottom through the open channels.
!
    DO I = 1,9
      DO J = 13,14
        H(I,J) = HAVER1
      END DO
    END DO
    DO I = 15,18
      DO J = 1,9
        H(I,J) = HAVER2
      END DO
    END DO
!
  END DO
ENDIF
!
!Compute the maximum depth in the region.
!
DEPMAX = 0.0
DO I = 1,IM
  DO J =1,JM
    DEPMAX = MAX(H(I,J),DEPMAX)
  END DO
END DO
!
!Define COR.
!
COR = 1.3D-4
!
!Initialize FSM, DUM and DVM.
!
FSM = 1.D0
DUM = 1.D0
DVM = 1.D0
!
!
!Define the minimum allowed depth of a sea cell.
!
DO J = 1,JM
  DO I = 1,IM
    IF(H(I,J).LT.DEPMIN) THEN
      FSM(I,J)=0.
      DUM(I,J)=0.
      DVM(I,J)=0.
    ENDIF
  END DO
END DO
!
!  Compute area of the surface of the fjord system
!
AREA = 0.
DO I = 1,IM
  DO J = 1,JM
    IF (FSM(I,J).GT.0.) THEN
      AREA = AREA + 1.
    ENDIF
  END DO
END DO
AREA = AREA*DX*DY
WRITE(*,*)'AREA of the surface of the fjords is',AREA
!
!DVM is zero in all V-points with land on one side.
!
DO J = 1,JM-1
  DO I = 1,IM
    IF(FSM(I,J).EQ.0..AND.FSM(I,J+1).NE.0.) THEN
      DVM(I,J+1)=0.
    ENDIF
  END DO
END DO
!
!DUM is zero in all U-points with land on one side.
!
DO J = 1,JM
  DO I = 1,IM-1
    IF(FSM(I,J).EQ.0..AND.FSM(I+1,J).NE.0.) THEN
      DUM(I+1,J)=0.
    ENDIF
  END DO
END DO
!
!Compute the model static depths H, HU and HV.
!
H(1:IM,1:JM) = FSM(1:IM,1:JM)*H(1:IM,1:JM)
HU(1,1:JM) = H(1,1:JM)*DUM(1,1:JM)
HU(2:IM,1:JM) = 0.5*DUM(2:IM,1:JM)*(H(1:IM-1,1:JM)+H(2:IM,1:JM))
HV(1:IM,1) = H(1:IM,1)*DVM(1:IM,1)
HV(1:IM,2:JM) = 0.5*DVM(1:IM,2:JM)*(H(1:IM,1:JM-1)+H(1:IM,2:JM))
 
!
!  Define Weights to be used in the Coriolis averaging.
!
  DO I = 1,IM
     DO J = 1,JM
        HVSQR(I,J) = 0.D0
        IF (DVM(I,J).NE.0.) THEN
           HVSQR(I,J) = SQRT(DBLE(HV(I,J)))
        ENDIF
        HUSQR(I,J) = 0.D0
        IF (DUM(I,J).NE.0.) THEN
           HUSQR(I,J) = SQRT(DBLE(HU(I,J)))
        ENDIF
        IF (DVM(I,J).GT.0. .AND. HVSQR(I,J).LT.1.0) THEN
           WRITE(*,*)'ERROR IN HVSQR'
           WRITE(*,*)I,J,HVSQR(I,J)
           STOP
        ENDIF
        IF (DUM(I,J).GT.0. .AND. HUSQR(I,J).LT.1.0) THEN
           WRITE(*,*)'ERROR IN HUSQR'
           WRITE(*,*)I,J,HUSQR(I,J)
           STOP
        ENDIF
     END DO
  END DO
          
!
!Define layer thicknesses.
!
CALL DEPTH(KB,Z,DZ,DZR,DZZ,ZZ,DSBOT)
!
!  Define the bottom drag coefficients.
!
CBC = 0.0
!
DO J = 1,JM
  DO I = 1,IM
    IF (FSM(I,J).GT.0.0) THEN
      CBC(I,J)=AMAX1(CD,.16/ALOG((ZZ(KB-1)-Z(KB))*H(I,J)/Z0)**2)
    ENDIF
  END DO
END DO
!
RETURN
END
