SUBROUTINE TIDEFRS(IS)
USE MOD_MAIN
IMPLICIT NONE
INTEGER IS
!
REAL TIMESEC
REAL PI,PHA,UP,DETA(KCON,2),DETASUM(2)
!
!  TIDEFRS updates the fields ETATFRS,UATFRS,VATFRS,UTFRS,VTFRS
!  as a function of time and the amplitudes and phases of the
!  tidal components
!  DETA is the difference of the water level from one cell
!  in the FRS-zone to the next for one component.
!  DETASUM is the sum over the components.
!
PI = 4.*ATAN(1.0)
TIMESEC = DT*(ISTEP-1) + DT*IS/N2D
ETATFRS = 0.
DETASUM = 0.
I = 1
J = 1
DO K = 1,KCON
      PHA = FREQ(K)*TIMESEC-ETATPHA(I,J,K)
100   IF (PHA.GT.0.0) THEN
       PHA = PHA - 2.*PI
        GO TO 100
      ENDIF
!
!  Compute the direction of the flow.
!
      IF(PHA.GE.-2*PI .AND. PHA.LT.-PI) THEN
        UP = -1.
      ELSE
        UP = +1.
      ENDIF
      ETATFRS(I,J) =  ETATFRS(I,J) + ETATAMP(I,J,K)*COS(FREQ(K)*TIMESEC-ETATPHA(I,J,K))
      DETA(K,1) = ETATAMP(I,J,K)*(COS(FREQ(K)*TIMESEC-ETATPHA(I,J,K))- &
     &          COS(UP*FREQ(K)*DX/SQRT(GRAV*H(1,13))+FREQ(K)*TIMESEC-ETATPHA(I,J,K)) )
      DETA(K,2) = ETATAMP(I,J,K)*(COS(FREQ(K)*TIMESEC-ETATPHA(I,J,K))- &
     &          COS(UP*FREQ(K)*DX/SQRT(GRAV*H(15,1))+FREQ(K)*TIMESEC-ETATPHA(I,J,K)) )
      DETA(K,1:2) = UP*ABS(DETA(K,1:2))
      DETASUM(1) = DETASUM(1) - DETA(K,1)
      DETASUM(2) = DETASUM(2) - DETA(K,2)
END DO
!
!  Then define ETATFRS through the FRS-zones such that d(ETA)/dX is
!  correct assuming that the speed of the wave is SQRT(GRAV*H).
!
DO I = 1,LB
  DO J = 13,14
    ETATFRS(I,J) = ETATFRS(1,1) + (I-LB)*DETASUM(1)
  END DO
END DO
DO I = 15,18
  DO J = 1,LB
    ETATFRS(I,J) = ETATFRS(1,1) + (J-LB)*DETASUM(2)
  END DO
END DO
!
UATFRS = 0.
VATFRS = 0.
!
!  Then the same for the velocities.
!
!
DETASUM = 0.
I = 1
J = 1
DO K = 1,KCON
      PHA = FREQ(K)*TIMESEC-ETATPHA(I,J,K)
200   IF (PHA.GT.0.0) THEN
       PHA = PHA - 2.*PI
        GO TO 200
      ENDIF
      IF(PHA.GE.-2*PI .AND. PHA.LT.-PI) THEN
        UP = -1.
      ELSE
        UP = +1.
      ENDIF
      UATFRS(I,J) =  UATFRS(I,J) + UATAMP(1,13,K)*COS(FREQ(K)*TIMESEC-UATPHA(I,J,K))
      VATFRS(I,J) =  VATFRS(I,J) + VATAMP(15,1,K)*COS(FREQ(K)*TIMESEC-VATPHA(I,J,K))
      DETA(K,1) = UATAMP(1,13,K)*(COS(FREQ(K)*TIMESEC-UATPHA(I,J,K))- &
     &          COS(UP*FREQ(K)*DX/SQRT(GRAV*H(1,13))+FREQ(K)*TIMESEC-UATPHA(I,J,K)) )
      DETA(K,2) = VATAMP(15,1,K)*(COS(FREQ(K)*TIMESEC-VATPHA(I,J,K))- &
     &          COS(UP*FREQ(K)*DX/SQRT(GRAV*H(15,1))+FREQ(K)*TIMESEC-VATPHA(I,J,K)) )
      DETA(K,1:2) = UP*ABS(DETA(K,1:2))
      DETASUM(1) = DETASUM(1) - DETA(K,1)
      DETASUM(2) = DETASUM(2) - DETA(K,2)
END DO
!
!  Then define UATFRS through the FRS-zones such that d(UA)/dX is
!  correct assuming that the speed of the wave is SQRT(GRAV*H).
!
DO I = 1,LB
  DO J = 13,14
    UATFRS(I,J) = UATFRS(1,1) + (I-LB)*DETASUM(1)
  END DO
END DO
DO I = 15,18
  DO J = 1,LB
    VATFRS(I,J) = VATFRS(1,1) + (J-LB)*DETASUM(2)
  END DO
END DO
UTFRS = 0.
VTFRS = 0.
DO I = 1,IM
  DO J = 1,JM
    DO K = 1,KB-1
      UTFRS(I,J,K) = UATFRS(I,J)
      VTFRS(I,J,K) = VATFRS(I,J)
    END DO
  END DO
END DO
!
RETURN
END
