SUBROUTINE TIDEINIT
!
!  TIDEINIT initializes the tidal forcing fields FREQ, ETATAMP, ETATPHA,
!  UATAMP, UATPHA, VATAMP and VATPHA to be used at the open bounaries to force in the
!  tidal components.
!
USE MOD_BOUND
IMPLICIT NONE
!
REAL PI
INTEGER K
INTEGER I,J
!
PI = 4.*ATAN(1.0)
!
!  Define the frequencies in radians per second.
!
FREQ(1) = 28.984*PI/(180.*3600.)  !  M2
FREQ(2) = 30.000*PI/(180.*3600.)  !  S2
FREQ(3) = 28.440*PI/(180.*3600.)  !  N2
FREQ(4) = 15.041*PI/(180.*3600.)  !  K1
!
!  Define the phases and amplitudes of the tidal fields.
!
ETATAMP(1:IM,1:JM,1) = 0.452  ! From tidal tabels from Norway
ETATAMP(1:IM,1:JM,2) = 0.163 
ETATAMP(1:IM,1:JM,3) = 0.089
ETATAMP(1:IM,1:JM,4) = 0.034
!
ETATPHA(1:IM,1:JM,1) = 288.2*PI/180.
ETATPHA(1:IM,1:JM,2) = 327.1*PI/180.
ETATPHA(1:IM,1:JM,3) = 267.8*PI/180.
ETATPHA(1:IM,1:JM,4) = 160.1*PI/180.
!
! As for now we are lacking data on the tidal velocities.
! And compute the amplitudes and phases as functions of
! the amplitude and phase of the water elevation.
!
UATAMP = 0.
VATAMP = 0.
DO I = 1,IM
  DO J = 1,JM
    IF (DUM(I,J).GT.0.) THEN
      DO K = 1,4
        UATAMP(I,J,K) = SQRT(GRAV*HU(I,J))*ETATAMP(I,J,K)/HU(I,J)
      END DO
    ENDIF
    IF (DVM(I,J).GT.0.) THEN
      DO K = 1,4
        VATAMP(I,J,K) = SQRT(GRAV*HV(I,J))*ETATAMP(I,J,K)/HV(I,J)
      END DO
    ENDIF
  END DO
END DO
!
UATPHA(1:IM,1:JM,1:4) = ETATPHA(1:IM,1:JM,1:4) - PI/2
VATPHA(1:IM,1:JM,1:4) = ETATPHA(1:IM,1:JM,1:4) - PI/2
!
!
RETURN
END


